Hex encoding/decoding utilities
Efficient bidirectional conversion between dodecets and hex strings.
Functions
- decode
- Decode a hex string to a vector of dodecets
- decode_
dodecet - Decode 3 hex characters to a single dodecet
- dodecet_
count - Calculate the number of dodecets in a hex string
- encode
- Encode a slice of dodecets to a hex string
- encode_
dodecet - Encode a single dodecet to 3 hex characters
- equal_
ignore_ case - Compare two hex strings for equality (case-insensitive)
- format_
spaced - Format a hex string with spacing for readability
- hex_
view - Create a hex editor-friendly view
- is_
valid - Validate a hex string for dodecet encoding
- remove_
spaces - Remove spaces from a spaced hex string
- to_
lowercase - Convert hex string to lowercase
- to_
uppercase - Convert hex string to uppercase
- xor
- XOR two hex strings of equal length